@@ -2,8 +2,8 @@ from pathlib import Path
 import sys
 
 from talon_git_labeller.commands import git_branch, git_status
-from talon_git_labeller.const import PLATFORM, USER_SUBFOLDER, GIT_BRANCH_ITEMS_LIST, GIT_STATUS_ITEMS_LIST
-from talon_git_labeller.helpers import get_talon_user_path, sort_out_windows_colours
+from talon_git_labeller.const import USER_SUBFOLDER, GIT_BRANCH_ITEMS_LIST, GIT_STATUS_ITEMS_LIST
+from talon_git_labeller.helpers import get_talon_user_path
 from talon_git_labeller.write import dump_list_file
 
 
@@ -17,9 +17,6 @@ def main():
     labeller_dir = user_dir / USER_SUBFOLDER
     labeller_dir.mkdir(exist_ok=True)
 
-    if PLATFORM == "windows":
-        sort_out_windows_colours()
-
     if cmd == "git-tl-branch":
         target = labeller_dir / "branch.py"
         branch_map = git_branch()
